@@ -1,4 +1,4 @@
-__version__ = '0.1.9'
+__version__ = '0.1.12'
 
 import pymongo
 import pandas as pd
@@ -168,13 +168,22 @@ class mlist():
                 temp_map[item[key]] = item
         return temp_map
 
-    def tranlate_header(data, col_dict):
+    def header_handler(data, options):
         result_data = []
         for row in data:
             temp = {}
             for key in row.keys():
                 if key != "":
-                    temp[col_dict[key]] = row[key]
+                    temp[options[key]] = row[key]
+            result_data.append(temp)
+        return result_data
+
+    def field_handler(data, options):
+        result_data = []
+        for row in data:
+            temp = row
+            for key in options.keys():
+                temp[key] = options[key](row[key])
             result_data.append(temp)
         return result_data
 
@@ -190,12 +199,12 @@ class mdict():
 
 class mdb():
 
-    def connect_mongodb(options):
+    def connect_mongodb(options, db):
         DB_HOST = options['DB_HOST']
         DB_PORT = options['DB_PORT']
         DB_USER = options['DB_USER']
         DB_PASS = options['DB_PASS']
-        DB_DB = options['DB_DB']
+        DB_DB = db
 
         if DB_USER == "":
             myclient = pymongo.MongoClient("mongodb://%s:%s/" % (DB_HOST, DB_PORT))
@@ -208,6 +217,29 @@ class mdb():
         return myclient[DB_DB]
 
 
+class mcol():
+    def __init__(self, data_list):
+        self.data_list = data_list
+
+    def find_one(self, options):
+        for i in self.data_list:
+            for j in options.keys():
+                if (j in i.keys()) and (i[j] == options[j]):
+                    return i
+        return {}
+
+    def find(self, options):
+        result = []
+        for i in self.data_list:
+            bool_array = []
+            for j in options.keys():
+                if j in i.keys():
+                    bool_array.append(i[j] == options[j])
+            if (len(bool_array) > 0) and (not False in bool_array):
+                result.append(i)
+        return result
+
+
 def main():
     pass
 
